package VMOMI::HostProfileManagerAnswerFileStatus;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
